geowatch.tasks.invariants.pretext\_model module
===============================================

.. automodule:: geowatch.tasks.invariants.pretext_model
   :members:
   :undoc-members:
   :show-inheritance:
